timespantools.offset_happens_after_timespan_stops
=================================================

.. autofunction:: abjad.tools.timespantools.offset_happens_after_timespan_stops.offset_happens_after_timespan_stops
